@@ -1,9 +1,9 @@
 package Text::Table::Span;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-15'; # DATE
+our $DATE = '2021-02-16'; # DATE
 our $DIST = 'Text-Table-Span'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -449,7 +449,7 @@ Text::Table::Span - Text::Table::Tiny + support for column/row spans
 
 =head1 VERSION
 
-This document describes version 0.002 of Text::Table::Span (from Perl distribution Text-Table-Span), released on 2021-02-15.
+This document describes version 0.003 of Text::Table::Span (from Perl distribution Text-Table-Span), released on 2021-02-16.
 
 =head1 SYNOPSIS
 
@@ -699,7 +699,10 @@ feature.
 
 L<Text::Table::TinyBorderStyle>
 
-HTML &lt;TABLE&gt; element,
+L<Acme::CPANModules::TextTable> contains a comparison and benchmark for modules
+that generate text table.
+
+HTML E<lt>TABLEE<gt> element,
 L<https://www.w3.org/TR/2014/REC-html5-20141028/tabular-data.html>,
 L<https://www.w3.org/html/wiki/Elements/table>
 
